﻿using System.Diagnostics;
using System.Drawing;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9323
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;

            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\AppData\states.shp");
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColors.Black);
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(shapeFileLayer);
            map.Overlays.Add(layerOverlay);

            layerOverlay.WrappingMode = WrappingMode.WrapDateline;
            layerOverlay.WrappingExtent = new RectangleShape(-180, 90, 180, -90);


            map.CurrentExtent = new RectangleShape(-622.8658755, 454.56024575, 479.6341245, -335.75225425);

            map.TrackOverlay.TrackMode = TrackMode.Rectangle;
            map.TrackOverlay.TrackEnded += TrackOverlay_TrackEnded;


            map.Refresh();
        }

        private void TrackOverlay_TrackEnded(object sender, TrackEndedTrackInteractiveOverlayEventArgs e)
        {
            RectangleShape rect = map.TrackOverlay.TrackShapeLayer.InternalFeatures[0].GetBoundingBox();
            map.TrackOverlay.TrackShapeLayer.Clear();
            map.TrackOverlay.Refresh();

            RectangleShape worldRect = map.CurrentExtent;

            Bitmap currentBitmap = map.GetBitmap((int)map.ActualWidth, (int)map.ActualHeight);

            DrawingRectangle rectInScreen = ExtentHelper.ToScreenCoordinate(worldRect, rect, (float)map.ActualWidth, (float)map.ActualHeight);

            Bitmap newBitmap = new Bitmap(rectInScreen.Width, rectInScreen.Height);
            PlatformGeoCanvas canvas = new PlatformGeoCanvas();
            canvas.BeginDrawing(newBitmap, rect, GeographyUnit.DecimalDegree);
            GeoImage image = new GeoImage(currentBitmap);
            canvas.DrawWorldImageWithoutScaling(image, worldRect.GetCenterPoint().X, worldRect.GetCenterPoint().Y, DrawingLevel.LabelLevel);
            canvas.EndDrawing();

            newBitmap.Save("test.jpg");
            Process.Start("test.jpg");
        }
    }
}
